from django.test import TestCase
from content.models import TestingQuestion, TestingBank
from organisation.models import Course, Module, CourseModuleRel


class TestContent(TestCase):

    def create_course(self, name="course name", **kwargs):
        return Course.objects.create(name=name, **kwargs)

    def create_module(self, name, course, **kwargs):
        module = Module.objects.create(name=name, **kwargs)
        rel = CourseModuleRel.objects.create(course=course, module=module)
        module.save()
        rel.save()
        return module

    def create_testing_bank(self, name, module, **kwargs):
        return TestingBank.objects.create(name=name, module=module, **kwargs)

    def create_test_question(self, name, module, **kwargs):
        return TestingQuestion.objects.create(name=name, module=module, **kwargs)

    def setUp(self):
        self.course = self.create_course()
        self.module = self.create_module('module', self.course)
        self.question = self.create_test_question('question', self.module)

    def test_html_sanitize(self):
        content = "<body><head></head><p><b><strike><img>" \
                  "<a href='/test'>Test</a><strike></b></p></body>"

        self.question.question_content = content
        self.question.save()

        self.assertEquals(
            self.question.question_content,
            '<div style="vertical-align:middle;'
            'display:inline-block;width:80%"><b>'
            '<img style="vertical-align:middle"/>'
            '<a href="/test">Test</a></b></div>')



from django.conf import settings
from communication.models import Sms
import requests
from django.contrib.sites.models import Site
from go_http import HttpApiSender, LoggingSender
import koremutake
from django.contrib.auth.hashers import make_password
from random import randint
import logging

# Get an instance of a logger
logger = logging.getLogger(__name__)


def get_autologin_link(unique_token):
    if unique_token is not None:
        return 'http://%s/%s/%s' % (
            Site.objects.get_current().domain,
            'a',
            unique_token
        )
    else:
        return None


class VumiSmsApi:

    """Sends vumi http api requests"""

    def __init__(self):

        if hasattr(settings, 'VUMI_GO_FAKE') and settings.VUMI_GO_FAKE:
            self.sender = LoggingSender(
                'DEBUG'
            )
        else:
            self.sender = HttpApiSender(
                account_key=settings.VUMI_GO_ACCOUNT_KEY,
                conversation_key=settings.VUMI_GO_CONVERSATION_KEY,
                conversation_token=settings.VUMI_GO_ACCOUNT_TOKEN
            )

    def prepare_msisdn(self, msisdn):
        if msisdn.startswith('+'):
            return msisdn
        else:
            if msisdn.startswith('27'):
                return '+' + msisdn
            elif msisdn.startswith('0'):
                return '+27' + msisdn[1:]


    def templatize(self, message, password, autologin):
        if password is not None:
            message = message.replace("|password|", password)
        if autologin is not None:
            message = message.replace("|autologin|", autologin)
        return message

    def save_sms_log(self, uuid, message, timestamp, msisdn):
        # Create sms object
        sms = Sms.objects.create(
            uuid=uuid,
            message=message,
            date_sent=timestamp,
            msisdn=msisdn
        )
        sms.save()
        return sms

    def send(self, msisdn, message, password, autologin):
        # Send the url
        message = self.templatize(message, password, autologin)
        msisdn = self.prepare_msisdn(msisdn)
        try:
            response = self.sender.send_text(to_addr=msisdn, content=message)
        except requests.exceptions.RequestException as e:
            sent = False
            logger.error(e)
            return None, sent

        if u'success' in response.keys() and response[u'success'] is False:
            sms = self.save_sms_log(response[u'success'], message,
                                    None, msisdn)
            sent = False
        else:
            sms = self.save_sms_log(response[u'message_id'], message,
                                    response[u'timestamp'], msisdn)
            sent = True

        return sms, sent

    def send_all(self, queryset, message):
        # Check if a password or autologin message
        is_welcome_message = False
        is_autologin_message = False
        if "|password|" in message:
            is_welcome_message = True
        if "|autologin|" in message:
            is_autologin_message = True

        successful = 0
        fail = []
        for learner in queryset:
            password = None
            if is_welcome_message:
                # Generate password
                password = koremutake.encode(randint(10000, 100000))
                learner.password = make_password(password)
            if is_autologin_message:
                # Generate autologin link
                learner.generate_unique_token()
            learner.save()

            # Send sms
            try:
                sms, sent = self.send(
                    learner.username,
                    message=message,
                    password=password,
                    autologin=get_autologin_link(learner.unique_token)
                )
            except:
                sent = False
                pass

            if sent:
                successful += 1
            else:
                fail.append(learner.username)

            # Save welcome message details
            if is_welcome_message and sent:
                learner.welcome_message = sms
                learner.welcome_message_sent = True

            learner.save()

        return successful, fail



from django.contrib import admin
from core.models import *

from core.filters import FirstNameFilter, LastNameFilter, MobileFilter, \
    ParticipantFirstNameFilter, ParticipantLastNameFilter, \
    ParticipantMobileFilter, ParticipantFilter, LearnerFilter


class ParticipantInline(admin.TabularInline):
    model = Participant
    extra = 1
    raw_id_fields = ('learner',)
    readonly_fields = ('get_firstname', 'get_lastname', 'get_mobile')
    exclude = ('points',)


    def get_firstname(self, obj):
        return obj.learner.first_name
    get_firstname.short_description = 'First Name'
    get_firstname.admin_order_field = 'learner__first_name'


    def get_lastname(self, obj):
        return obj.learner.last_name
    get_lastname.short_description = 'Last Name'
    get_lastname.admin_order_field = 'learner__last_name'

    def get_mobile(self, obj):
        return obj.learner.mobile
    get_mobile.short_description = 'Mobile'
    get_mobile.admin_order_field = 'learner__mobile'


class ClassAdmin(admin.ModelAdmin):
    list_display = ("course", "name", "description")
    list_filter = ("course", )
    search_fields = ("name", "description")
    fieldsets = [
        (None, {"fields": ["name", "description", "course"]}),
        ("Classification", {"fields": ["type", "startdate", "enddate"]})
    ]
    inlines = (ParticipantInline,)


class ParticipantQuestionAnswerAdmin(admin.ModelAdmin):
    list_display = (
        "participant",
        "get_firstname",
        "get_lastname",
        "get_mobile",
        "question",
        "answerdate",
        "option_selected",
        "correct")
    list_filter = (
        ParticipantFilter,
        "question",
        FirstNameFilter,
        LastNameFilter,
        MobileFilter)
    search_fields = ('participant__learner__first_name',
                     'participant__learner__last_name',
                     'participant__learner__mobile')
    inline = (ParticipantInline,)

    def get_firstname(self, obj):
        return obj.participant.learner.first_name
    get_firstname.short_description = 'First Name'
    get_firstname.admin_order_field = 'participant__learner__first_name'

    def get_lastname(self, obj):
        return obj.participant.learner.last_name
    get_lastname.short_description = 'Last Name'
    get_lastname.admin_order_field = 'participant__learner__last_name'

    def get_mobile(self, obj):
        return obj.participant.learner.mobile
    get_mobile.short_description = 'Mobile'
    get_mobile.admin_order_field = 'participant__learner__mobile'


class ParticipantPointInline(admin.TabularInline):
    model = Participant.pointbonus.through
    list_display = ("pointbonus", "scenario")


class ParticipantAdmin(admin.ModelAdmin):
    list_display = ("learner", "get_firstname",
        "get_lastname", "classs" '')
    list_filter = (
        LearnerFilter,
        "classs",
        ParticipantFirstNameFilter,
        ParticipantLastNameFilter,
        ParticipantMobileFilter)
    search_fields = ("learner",)
    inlines = [ParticipantPointInline, ]

    def get_firstname(self, obj):
        return obj.learner.first_name
    get_firstname.short_description = 'First Name'
    get_firstname.admin_order_field = 'learner__first_name'

    def get_lastname(self, obj):
        return obj.learner.last_name
    get_lastname.short_description = 'Last Name'
    get_lastname.admin_order_field = 'learner__last_name'


# Organisation
admin.site.register(Class, ClassAdmin)
admin.site.register(ParticipantQuestionAnswer, ParticipantQuestionAnswerAdmin)
admin.site.register(Participant, ParticipantAdmin)



from __future__ import absolute_import

from mobileu.celery import app
from go_http import HttpApiSender
from django.conf import settings
from communication.utils import VumiSmsApi
from datetime import datetime
from django.core.mail import mail_managers

@app.task
def update_metric(name, value, metric_type):
    sender = HttpApiSender(
        account_key=settings.VUMI_GO_ACCOUNT_KEY,
        conversation_key=settings.VUMI_GO_CONVERSATION_KEY,
        conversation_token=settings.VUMI_GO_ACCOUNT_TOKEN
    )
    sender.fire_metric(name, value, agg=metric_type)


@app.task
def send_sms(msisdn, message, password, autologin):
    vumi_api = VumiSmsApi()
    sms, sent = vumi_api.send(msisdn, message, password, autologin)


@app.task(default_retry_delay=300, max_retries=5)
def bulk_send_all(queryset, message):
    vumi_api = VumiSmsApi()
    successful, fail = vumi_api.send_all(queryset, message)
    subject = 'Vumi SMS Send'
    message = "\n".join([
        "Message: " + message,
        "Time: " + str(datetime.now()),
        "Successful sends: " + str(successful),
        "Failures: " + ", ".join(fail)
    ])

    mail_managers(
        subject=subject,
        message=message,
        fail_silently=False
    )

    return successful, fail



from django.shortcuts import render_to_response
from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.conf import settings
from import_export.admin import ImportExportModelAdmin
from communication.utils import VumiSmsApi, get_autologin_link
from auth.forms import SendSmsForm
from communication.tasks import bulk_send_all
from django import template
from auth.models import Learner, SystemAdministrator, SchoolManager,\
    CourseManager, CourseMentor
from .forms import SystemAdministratorChangeForm, \
    SystemAdministratorCreationForm, SchoolManagerChangeForm,\
    SchoolManagerCreationForm, CourseManagerChangeForm, \
    CourseManagerCreationForm, CourseMentorChangeForm, \
    CourseMentorCreationForm, LearnerChangeForm, LearnerCreationForm

from core.models import ParticipantQuestionAnswer
from auth.resources import LearnerResource
from auth.filters import CourseFilter, AirtimeFilter


class SystemAdministratorAdmin(UserAdmin):
    # The forms to add and change user instances
    form = SystemAdministratorChangeForm
    add_form = SystemAdministratorCreationForm

    list_display = ("username", "last_name", "first_name", "country", "area")
    list_filter = ("country", "area")
    search_fields = ("last_name", "first_name", "username")
    ordering = ("country", "area", "last_name")
    filter_horizontal = ()

    fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name", "email",
                                      "mobile")}),
        ("Access", {"fields": ("username", "password", "is_active")}),
        ("Permissions", {"fields": ("is_staff", "is_superuser")}),
        ("Important dates", {"fields": ("last_login", "date_joined")})
    )
    # add_fieldsets is not a standard ModelAdmin attribute. UserAdmin
    # overrides get_fieldsets to use this attribute when creating a user.
    add_fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name")}),
        ("Access", {"fields": ("username", "password1",
                               "password2")}),
        ("Region", {"fields": ("country",)})
    )


class SchoolManagerAdmin(UserAdmin):
    # The forms to add and change user instances
    form = SchoolManagerChangeForm
    add_form = SchoolManagerCreationForm

    list_display = ("username", "last_name", "first_name", "country", "area")
    list_filter = ("country", "area")
    search_fields = ("last_name", "first_name", "username")
    ordering = ("country", "area", "last_name")
    filter_horizontal = ()

    fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name",
                                      "email", "mobile")}),
        ("Access", {"fields": ("username", "password",
                               "is_active")}),
        ("Region", {"fields": ("country", "area", "city",
                               "school")}),
        ("Important dates", {"fields": ("last_login", "date_joined")})
    )
    # add_fieldsets is not a standard ModelAdmin attribute. UserAdmin
    # overrides get_fieldsets to use this attribute when creating a user.
    add_fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name")}),
        ("Access", {"fields": ("username", "password1",
                               "password2")}),
        ("Region", {"fields": ("country", "area", "school")})
    )


class CourseManagerAdmin(UserAdmin):
    # The forms to add and change user instances
    form = CourseManagerChangeForm
    add_form = CourseManagerCreationForm

    list_display = ("username", "last_name", "first_name", "country", "area")
    list_filter = ("country", "area")
    search_fields = ("last_name", "first_name", "username")
    ordering = ("country", "area", "last_name")
    filter_horizontal = ()

    fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name",
                                      "email", "mobile")}),
        ("Access", {"fields": ("username", "password",
                               "is_active")}),
        ("Region", {"fields": ("country", "area", "city",
                               "course")}),
        ("Important dates", {"fields": ("last_login", "date_joined")})
    )
    # add_fieldsets is not a standard ModelAdmin attribute. UserAdmin
    # overrides get_fieldsets to use this attribute when creating a user.
    add_fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name")}),
        ("Access", {"fields": ("username", "password1",
                               "password2")}),
        ("Region", {"fields": ("country", "area", "course")})
    )


class CourseMentorAdmin(UserAdmin):
    # The forms to add and change user instances
    form = CourseMentorChangeForm
    add_form = CourseMentorCreationForm

    list_display = ("username", "last_name", "first_name", "country", "area")
    list_filter = ("country", "area")
    search_fields = ("last_name", "first_name", "username")
    ordering = ("country", "area", "last_name")
    filter_horizontal = ()

    fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name",
                                      "email", "mobile")}),
        ("Access", {"fields": ("username", "password",
                               "is_active")}),
        ("Region", {"fields": ("country", "area", "city",
                               "course")}),
        ("Important dates", {"fields": ("last_login", "date_joined")})
    )
    # add_fieldsets is not a standard ModelAdmin attribute. UserAdmin
    # overrides get_fieldsets to use this attribute when creating a user.
    add_fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name")}),
        ("Access", {"fields": ("username", "password1",
                               "password2")}),
        ("Region", {"fields": ("country", "area", "course")})
    )


class LearnerAdmin(UserAdmin, ImportExportModelAdmin):
    # The forms to add and change user instances
    form = LearnerChangeForm
    add_form = LearnerCreationForm
    resource_class = LearnerResource
    list_max_show_all = 1000
    # The fields to be used in displaying the User model.
    # These override the definitions on the base UserAdmin
    # that reference specific fields on auth.User.
    list_display = ("username", "first_name", "last_name", "school",
                    "area", "completed_questions", "percentage_correct",
                    "welcome_message_sent")
    list_filter = ("first_name", "last_name", "mobile", 'school', "country",
                   "area", "welcome_message_sent", CourseFilter, AirtimeFilter)
    search_fields = ("last_name", "first_name", "username")
    ordering = ("country", "area", "last_name", "first_name", "last_login")
    filter_horizontal = ()
    readonly_fields = ("mobile",)

    fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name",
                                      "email", "mobile")}),
        ("Access", {"fields": ("username", "password",
                               "is_active", "unique_token")}),
        ("Region", {"fields": ("country", "area", "city",
                               "school")}),
        ("Opt-In Communications", {"fields": ("optin_sms", "optin_email")}),
        ("Important dates", {"fields": ("last_login", "date_joined")})
    )
    # add_fieldsets is not a standard ModelAdmin attribute. UserAdmin
    # overrides get_fieldsets to use this attribute when creating a user.
    add_fieldsets = (
        ("Personal info", {"fields": ("first_name", "last_name")}),
        ("Access", {"fields": ("username", "password1",
                               "password2")}),
        ("Region", {"fields": ("country", "area", "school")})
    )

    def send_sms(self, request, queryset):
        form = None
        if 'apply' in request.POST:
            form = SendSmsForm(request.POST)

            if form.is_valid():
                vumi = VumiSmsApi()
                message = form.cleaned_data["message"]

                if queryset.count() <= settings.MIN_VUMI_CELERY_SEND:
                    successful, fail = vumi.send_all(queryset, message)
                    async = False
                else:
                    #Use celery task
                    bulk_send_all.delay(queryset, message)
                    successful = 0
                    fail = []
                    async = True

                return render_to_response(
                    'admin/auth/sms_result.html',
                    {
                        'redirect': request.get_full_path(),
                        'success_num': successful,
                        'fail': fail,
                        'async': async
                    },
                )

        if not form:
            form = SendSmsForm(
                initial={
                    '_selected_action': request.POST.getlist(
                        admin.ACTION_CHECKBOX_NAME,
                    ),
                }
            )
        return render_to_response(
            'admin/auth/send_sms.html',
            {
                'sms_form': form,
                'learners': queryset
            },
            context_instance=template.RequestContext(request)
        )
    send_sms.short_description = "Send sms to learners"
    actions = ['send_sms']

    def completed_questions(self, learner):
        return ParticipantQuestionAnswer.objects.filter(
            participant__learner=learner
        ).count()
    completed_questions.short_description = "Completed Questions"
    completed_questions.allow_tags = True
    completed_questions.admin_order_field = 'participant__learner'

    def percentage_correct(self, learner):
        complete = self.completed_questions(learner)
        if complete > 0:
            return ParticipantQuestionAnswer.objects.filter(
                participant__learner=learner,
                correct=True
            ).count() * 100 / complete
        else:
            return 0
    percentage_correct.short_description = "Percentage correct"
    percentage_correct.allow_tags = True
    percentage_correct.admin_order_field = 'participant__learner'

# Auth
admin.site.register(SystemAdministrator, SystemAdministratorAdmin)
admin.site.register(SchoolManager, SchoolManagerAdmin)
admin.site.register(CourseManager, CourseManagerAdmin)
admin.site.register(CourseMentor, CourseMentorAdmin)
admin.site.register(Learner, LearnerAdmin)



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    depends_on = (
        ("content", "0001_initial"),
    )

    def forwards(self, orm):
        # Adding model 'Class'
        db.create_table(u'core_class', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=50, unique=True, null=True)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=50, blank=True)),
            ('course', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['organisation.Course'], null=True)),
            ('type', self.gf('django.db.models.fields.PositiveIntegerField')(default=1)),
            ('startdate', self.gf('django.db.models.fields.DateField')(null=True, blank=True)),
            ('enddate', self.gf('django.db.models.fields.DateField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'core', ['Class'])

        # Adding model 'Participant'
        db.create_table(u'core_participant', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('learner', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.Learner'])),
            ('classs', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['core.Class'])),
            ('datejoined', self.gf('django.db.models.fields.DateField')()),
            ('points', self.gf('django.db.models.fields.PositiveIntegerField')()),
        ))
        db.send_create_signal(u'core', ['Participant'])

        # Adding M2M table for field pointbonus on 'Participant'
        m2m_table_name = db.shorten_name(u'core_participant_pointbonus')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('participant', models.ForeignKey(orm[u'core.participant'], null=False)),
            ('gamificationpointbonus', models.ForeignKey(orm[u'gamification.gamificationpointbonus'], null=False))
        ))
        db.create_unique(m2m_table_name, ['participant_id', 'gamificationpointbonus_id'])

        # Adding M2M table for field badgetemplate on 'Participant'
        m2m_table_name = db.shorten_name(u'core_participant_badgetemplate')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('participant', models.ForeignKey(orm[u'core.participant'], null=False)),
            ('gamificationbadgetemplate', models.ForeignKey(orm[u'gamification.gamificationbadgetemplate'], null=False))
        ))
        db.create_unique(m2m_table_name, ['participant_id', 'gamificationbadgetemplate_id'])


    def backwards(self, orm):
        # Deleting model 'Class'
        db.delete_table(u'core_class')

        # Deleting model 'Participant'
        db.delete_table(u'core_participant')

        # Removing M2M table for field pointbonus on 'Participant'
        db.delete_table(db.shorten_name(u'core_participant_pointbonus'))

        # Removing M2M table for field badgetemplate on 'Participant'
        db.delete_table(db.shorten_name(u'core_participant_badgetemplate'))


    models = {
        u'auth.customuser': {
            'Meta': {'object_name': 'CustomUser'},
            'area': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'city': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'country': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "u'user_set'", 'blank': 'True', 'to': u"orm['auth.Group']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'mobile': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'optin_email': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'optin_sms': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "u'user_set'", 'blank': 'True', 'to': u"orm['auth.Permission']"}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        u'auth.group': {
            'Meta': {'object_name': 'Group'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        u'auth.learner': {
            'Meta': {'object_name': 'Learner', '_ormbases': [u'auth.CustomUser']},
            u'customuser_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': u"orm['auth.CustomUser']", 'unique': 'True', 'primary_key': 'True'}),
            'school': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['organisation.School']", 'null': 'True'})
        },
        u'auth.permission': {
            'Meta': {'ordering': "(u'content_type__app_label', u'content_type__model', u'codename')", 'unique_together': "((u'content_type', u'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['contenttypes.ContentType']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        u'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'core.class': {
            'Meta': {'object_name': 'Class'},
            'course': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['organisation.Course']", 'null': 'True'}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'enddate': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'unique': 'True', 'null': 'True'}),
            'startdate': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'type': ('django.db.models.fields.PositiveIntegerField', [], {'default': '1'})
        },
        u'core.participant': {
            'Meta': {'object_name': 'Participant'},
            'badgetemplate': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['gamification.GamificationBadgeTemplate']", 'symmetrical': 'False', 'blank': 'True'}),
            'classs': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['core.Class']"}),
            'datejoined': ('django.db.models.fields.DateField', [], {}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'learner': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['auth.Learner']"}),
            'pointbonus': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['gamification.GamificationPointBonus']", 'symmetrical': 'False', 'blank': 'True'}),
            'points': ('django.db.models.fields.PositiveIntegerField', [], {})
        },
        u'gamification.gamificationbadgetemplate': {
            'Meta': {'object_name': 'GamificationBadgeTemplate'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'unique': 'True', 'null': 'True'})
        },
        u'gamification.gamificationpointbonus': {
            'Meta': {'object_name': 'GamificationPointBonus'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'unique': 'True', 'null': 'True'}),
            'value': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True'})
        },
        u'organisation.course': {
            'Meta': {'object_name': 'Course'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'unique': 'True', 'null': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '50', 'blank': 'True'})
        },
        u'organisation.organisation': {
            'Meta': {'object_name': 'Organisation'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'unique': 'True', 'null': 'True'}),
            'website': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'})
        },
        u'organisation.school': {
            'Meta': {'object_name': 'School'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'unique': 'True', 'null': 'True'}),
            'organisation': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['organisation.Organisation']", 'null': 'True'}),
            'website': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'})
        }
    }

    complete_apps = ['core']


from django.test import TestCase
from datetime import datetime
from auth.models import Learner
from organisation.models import (Course, Module, School, Organisation,
                                 CourseModuleRel)
from core.models import (Participant, Class, ParticipantBadgeTemplateRel,
                         ParticipantQuestionAnswer)
from gamification.models import (GamificationBadgeTemplate,
                                 GamificationPointBonus,
                                 GamificationScenario)
from content.models import TestingQuestion, TestingQuestionOption, TestingBank


class TestMessage(TestCase):

    def create_course(self, name="course name", **kwargs):
        return Course.objects.create(name=name, **kwargs)

    def create_class(self, name, course, **kwargs):
        return Class.objects.create(name=name, course=course, **kwargs)

    def create_module(self, name, course, **kwargs):
        module = Module.objects.create(name=name, **kwargs)
        rel = CourseModuleRel.objects.create(course=course,module=module)
        module.save()
        rel.save()
        return module

    def create_organisation(self, name='organisation name', **kwargs):
        return Organisation.objects.create(name=name, **kwargs)

    def create_test_question(self, name, module, **kwargs):
        return TestingQuestion.objects.create(name=name, module=module, **kwargs)

    def create_test_question_option(self, name, question, correct=True):
        return TestingQuestionOption.objects.create(
            name=name, question=question, correct=correct)

    def create_testbank(self, name, module, **kwargs):
        return TestingBank.objects.create(name=name, module=module, **kwargs)

    def create_school(self, name, organisation, **kwargs):
        return School.objects.create(
            name=name,
            organisation=organisation,
            **kwargs)

    def create_learner(self, school, **kwargs):
        return Learner.objects.create(school=school, **kwargs)

    def create_participant(self, learner, classs, **kwargs):
        return Participant.objects.create(
            learner=learner,
            classs=classs,
            **kwargs)

    def create_badgetemplate(self, name='badge template name', **kwargs):
        return GamificationBadgeTemplate.objects.create(name=name, **kwargs)

    def create_pointbonus(self, name='point bonus name', **kwargs):
        return GamificationPointBonus.objects.create(name=name, **kwargs)

    def setUp(self):
        self.course = self.create_course()
        self.module = self.create_module('module name', self.course)
        self.classs = self.create_class('class name', self.course)

        self.organisation = self.create_organisation()
        self.school = self.create_school('school name', self.organisation)
        self.learner = self.create_learner(
            self.school,
            mobile="+27123456789",
            country="country")
        self.badge_template = self.create_badgetemplate()
        self.question = self.create_test_question('q1', self.module)
        self.option = self.create_test_question_option('opt_1', self.question)

        # create point bonus with value 5
        self.pointbonus = self.create_pointbonus(value=5)

        # create scenario
        self.scenario = GamificationScenario.objects.create(
            name='scenario name',
            event='test',
            course=self.course,
            module=self.module,
            point=self.pointbonus,
            badge=self.badge_template
        )
        self.participant = self.create_participant(
            self.learner,
            self.classs,
            datejoined=datetime.now()
        )

    def test_award_scenario(self):

        scenario_no_module = GamificationScenario.objects.create(
            name='event name no module',
            event='event name no module',
            course=self.course,
            module=None,
            point=self.pointbonus,
            badge=self.badge_template
        )
        scenario_no_module.save()

        # participant should have 0 points
        self.assertEquals(0, self.participant.points)

        # award points to participant
        self.participant.award_scenario('event name no module', self.module)
        self.participant.save()

        # participant should have 0 points
        self.assertEquals(0, self.participant.points)

        # check badge was awarded
        b = ParticipantBadgeTemplateRel.objects.get(
            participant=self.participant)
        self.assertTrue(b.awarddate)

    def test_answer_question_correctly(self):

        # participant should have 0 points
        self.assertEquals(0, self.participant.points)

        # award points to participant
        self.participant.answer(self.question, self.option)

        # test points have been awarded
        self.assertEqual(1, self.participant.points)

        # test that the correct ParticipantQuestionAnswer
        answer = ParticipantQuestionAnswer.objects.filter(
            participant=self.participant).first()
        self.assertNotEqual(answer, None)
        self.assertEqual(answer.question, self.question)
        self.assertEqual(answer.option_selected, self.option)
        self.assertEqual(answer.correct, self.option.correct)

        self.participant.save()

    def test_answer_question_incorrectly(self):
        # Set option to NOT correct
        self.option.correct = False

        # participant should have 0 points
        self.assertEquals(0, self.participant.points)

        # Answer question incorrectly
        self.participant.answer(self.question, self.option)

        # No test points have been awarded
        self.assertEqual(0, self.participant.points)

        self.participant.save()

    def test_get_scenarios_hierarchy(self):
        event = "test"

        # create scenario
        self.scenario_no_module = GamificationScenario.objects.create(
            name='scenario name no module',
            event='test',
            course=self.course,
            module=None,
            point=self.pointbonus,
            badge=self.badge_template
        )
        self.scenario_no_module.save()

        scenarios = self.participant.get_scenarios(event, self.module)
        self.assertEqual(scenarios.first(), self.scenario)

    def test_recalculate_points_only_right(self):
        question2 = self.create_test_question(name="testquestion2",
                                              module=self.module)

        option2 = self.create_test_question_option(name="option2",
                                                   question=question2,
                                                   correct=False)

        self.participant.answer(self.question, self.option)
        self.participant.answer(question2, option2)

        self.participant.points = 0

        self.participant.recalculate_total_points()
        self.assertEqual(self.participant.points, 1)



from django.db import models
from django.contrib.auth.models import AbstractUser
from organisation.models import School, Course
import random
import string
from datetime import datetime, timedelta
from communication.models import Sms
from django.utils import timezone


# Base class for custom MobileU user model
class CustomUser(AbstractUser):
    mobile = models.CharField(verbose_name="Mobile Phone Number",
                              max_length=50, blank=False, unique=True)
    country = models.CharField(verbose_name="Country", max_length=50,
                               blank=False)
    area = models.CharField(verbose_name="Local Area", max_length=50,
                            blank=True)
    city = models.CharField(verbose_name="City", max_length=50, blank=True)
    optin_sms = models.BooleanField(verbose_name="Opt-In SMS Communications",
                                    default=False)
    optin_email = models.BooleanField(
        verbose_name="Opt-In Email Communications", default=False)

    unique_token = models.CharField(
        verbose_name="Unique Login Token",
        max_length=500,
        blank=True,
        null=True
    )

    unique_token_expiry = models.DateTimeField(
        verbose_name="Unique Login Token Expiry",
        null=True,
        blank=True
    )

    def generate_valid_token(self):
        # Base 64 encode from random uuid bytes and make url safe
        self.unique_token = ''.join(
            random.choice(
                string.ascii_letters +
                string.digits) for i in range(8))

        # Calculate expiry date
        self.unique_token_expiry = datetime.now() + timedelta(days=30)

    def generate_unique_token(self):
        # Check if unique token needs regenerating
        if self.unique_token_expiry is None \
                or timezone.now() > self.unique_token_expiry:
            # Check uniqueness on generation
            self.generate_valid_token()
            while CustomUser.objects.filter(
                    unique_token=self.unique_token).exists():
                self.generate_valid_token()

    def __str__(self):
        return self.username


# System administrator with access to the admin console
class SystemAdministrator(CustomUser):

    class Meta:
        verbose_name = "System Administrator"
        verbose_name_plural = "System Administrators"


# A manager of a school
class SchoolManager(CustomUser):
    school = models.ForeignKey(School, null=True, blank=False)

    class Meta:
        verbose_name = "School Manager"
        verbose_name_plural = "School Managers"


# A manager of a course
class CourseManager(CustomUser):
    course = models.ForeignKey(Course, null=True, blank=False)

    class Meta:
        verbose_name = "Course Manager"
        verbose_name_plural = "Course Managers"


# A mentor for a course
class CourseMentor(CustomUser):
    course = models.ForeignKey(Course, null=True, blank=False)

    class Meta:
        verbose_name = "Course Mentor"
        verbose_name_plural = "Course Mentors"


# A learner
class Learner(CustomUser):
    school = models.ForeignKey(School, null=True, blank=False)
    last_maths_result = models.FloatField(
        verbose_name="Last Terms Mathematics Result",
        blank=True,
        null=True
    )
    grade = models.CharField(
        verbose_name="User Grade",
        max_length=50,
        blank=True,
        null=True
    )
    welcome_message_sent = models.BooleanField(
        verbose_name="Welcome SMS Sent",
        blank=True,
        default=False
    )
    welcome_message = models.ForeignKey(
        Sms,
        null=True,
        blank=True
    )
    last_active_date = models.DateTimeField(
        null=True,
        blank=True,
    )

    class Meta:
        verbose_name = "Learner"
        verbose_name_plural = "Learners"



from django.test import TestCase
from utils import strip_tags, align, format_width


class TestContent(TestCase):

    def test_strip_tags(self):
        content = "<p><b>Test</b></p>"
        result = strip_tags(content)
        self.assertEquals(result, "<b>Test</b>")

    def test_align_image_only(self):
        content = "<img/>"
        result = align(content)
        self.assertEquals(result, u'<div style="vertical-align:middle;'
                                  u'display:inline-block;width:80%">'
                                  u'<img style="vertical-align:middle"/>'
                                  u'</div>')

    def test_align_text_only(self):
        content = "Test"
        result = align(content)
        self.assertEquals(result, u'<div style="vertical-align:middle;'
                                  u'display:inline-block;width:80%">'
                                  u'Test</div>')

    def test_align_text_and_image(self):
        content = "<b>Test</b><img/>"
        result = align(content)
        self.assertEquals(result, u'<div style="vertical-align:middle;'
                                  u'display:inline-block;width:80%">'
                                  u'<b>Test</b><img style='
                                  u'"vertical-align:middle"/></div>')

    def test_align_double_image(self):
        content = "<img/><img/>"
        result = align(content)
        self.assertEquals(result, u'<div style="vertical-align:middle;'
                                  u'display:inline-block;width:80%">'
                                  u'<img style="vertical-align:middle"/>'
                                  u'<img style="vertical-align:middle"/>'
                                  u'</div>')

    def test_align_then_strip(self):
        content = "<b>Test</b><p></p><img/>"
        result = align(content)
        output = strip_tags(result)
        self.assertEquals(output, u'<div style="vertical-align:middle;'
                                  u'display:inline-block;width:80%">'
                                  u'<b>Test</b><img style="'
                                  u'vertical-align:middle"/></div>')

    def test_format_width(self):
        content = '<img style="width:300px"/>'
        result = format_width(content)
        self.assertEquals(result, u'<body><img style="width:100%"/></body>')

    def test_unicode_filter(self):
        content = u'<b>Test</b><p></p><img/>'
        result = align(content)
        output = strip_tags(result)
        self.assertEquals(output, u'<div style="vertical-align:middle;'
                                  u'display:inline-block;width:80%">'
                                  u'<b>Test</b><img style="'
                                  u'vertical-align:middle"/></div>')


from import_export import resources, fields
from datetime import datetime

from organisation.models import School
from auth.models import Learner
from core.models import ParticipantQuestionAnswer
from core.models import Participant, Class


class LearnerResource(resources.ModelResource):
    class_name = fields.Field(column_name=u'class')
    completed_questions = fields.Field(column_name=u'completed_questions')
    percentage_correct = fields.Field(column_name=u'percentage_correct')

    class Meta:
        model = Learner
        exclude = (
            'customuser_ptr', 'password', 'last_login', 'is_superuser',
            'groups', 'user_permissions', 'is_staff', 'is_active',
            'date_joined', 'unique_token', 'unique_token_expiry'
            'welcome_message_sent', 'welcome_message'
        )
        export_order = (
            'id',
            'username',
            'first_name',
            'last_name',
            'email',
            'school',
            'country',
            'area',
            'city',
            'optin_sms',
            'optin_email',
            'completed_questions',
            'percentage_correct',
            'class_name',
        )

    def dehydrate_class_name(self, learner):
        participant = Participant.objects.filter(learner=learner)
        if participant.first() is not None:
            return participant.first().classs.name
        else:
            return ""

    def dehydrate_school(self, learner):
        if learner.school is not None:
            return learner.school.name
        else:
            return ""

    def dehydrate_completed_questions(self, learner):
        return ParticipantQuestionAnswer.objects.filter(
            participant__learner=learner
        ).count()

    def dehydrate_percentage_correct(self, learner):
        complete = self.dehydrate_completed_questions(learner)
        if complete > 0:
            return ParticipantQuestionAnswer.objects.filter(
                participant__learner=learner,
                correct=True
            ).count() * 100 / complete
        else:
            return 0

    def get_or_init_instance(self, instance_loader, row):
        row[u'is_staff'] = False
        row[u'is_superuser'] = False
        row[u'is_active'] = True
        row[u'date_joined'] = datetime.now()
        row[u'welcome_message_sent'] = None
        row[u'welcome_message'] = None

        return super(resources.ModelResource, self) \
            .get_or_init_instance(instance_loader, row)

    def import_obj(self, obj, data, dry_run):
        school, created = School.objects.get_or_create(name=data[u'school'])
        data[u'school'] = school.id
        data[u'mobile'] = data[u'username']
        return super(resources.ModelResource, self)\
            .import_obj(obj, data, dry_run)

    def save_m2m(self, obj, data, dry_run):
        obj.class_name = data[u'class']
        classs = Class.objects.filter(name=data[u'class']).first()

        # If the course and respective class exist, create participant
        if classs and not dry_run:
            Participant.objects.create(
                learner=obj,
                classs=classs,
                datejoined=datetime.now(),
            )
        elif not classs and data[u'class'] is not None:
            error = ("Invalid class '%s' provided for user %s"
                     % (data[u'class'], data["username"]))
            raise Exception(error)

        return super(resources.ModelResource, self)\
            .save_m2m(obj, data, dry_run)



from datetime import datetime, timedelta
from django.db.models import Count
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from organisation.models import Course
from core.models import Participant, ParticipantQuestionAnswer


class CourseFilter(admin.SimpleListFilter):
    title = _('Course')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        return Course.objects.all().values_list('id', 'name')

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(participant__classs__course_id=self.value())


class AirtimeFilter(admin.SimpleListFilter):
    title = _('Airtime')
    parameter_name = 'name'

    def get_date_range(self):
        today = datetime.today()
        start = today - timedelta(days=today.weekday(), weeks=1)
        end = start + timedelta(days=7)
        return [start, end]

    def get_learner_ids(self):
        participants = ParticipantQuestionAnswer.objects.filter(
            answerdate__range=self.get_date_range(),
            correct=True
        ).values('participant').annotate(Count('participant'))

        filtered_participants = participants.filter(
            participant__count__gte=9
        ).values('participant')

        return Participant.objects.filter(
            id__in=filtered_participants
        ).values_list('learner', flat=True)

    def lookups(self, request, model_admin):
        return [('airtime_award', _('9 to 15 questions correct'))]

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            if self.value() == 'airtime_award':
                learners = self.get_learner_ids()
                return queryset.filter(id__in=learners)
            else:
                return queryset



from __future__ import absolute_import

import os

from celery import Celery
from django.conf import settings

# set the default Django settings module for the 'celery' program.
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'mobileu.settings')

app = Celery('mobileu.celery',
             broker=settings.BROKER_URL,
             include=settings.CELERY_IMPORTS)

# Using a string here means the worker will not have to
# pickle the object when using Windows.
app.config_from_object('django.conf:settings')
app.autodiscover_tasks(lambda: settings.INSTALLED_APPS, related_name='tasks')

app.conf.update(
    CELERY_RESULT_BACKEND='djcelery.backends.database:DatabaseBackend',
)



from bs4 import BeautifulSoup
import re
from django.utils.html import remove_tags


def format_width(value):
    soup = BeautifulSoup(value)
    tags = soup.find_all('img')
    for tag in tags:
        if tag is not None:
            if "style" in unicode(tag):
                width = re.findall(r'\d+', tag['style'])
                if width:
                    if int(width[0]) > 280:
                        tag['style'] = 'width:100%'

    if soup.body:
        body = get_content(soup)
    return unicode(body)


def align(value):

    soup = BeautifulSoup(value)
    tags = soup.find_all('img')
    if tags:
        for tag in tags:
            tag['style'] = 'vertical-align:middle'
    if soup.body:
        body = get_content(soup)
        return body_to_div(body, soup)
    else:
        return value


def strip_tags(value):
    content = remove_tags(value, "p")
    return u'%s' % content


def get_content(value):
    return value.body.extract()


def body_to_div(body, soup):
    remove_tags(unicode(body), "body")
    output = soup.new_tag("div")
    list = body.contents[:]
    for content in list:
        output.append(content)
        output['style'] = \
            'vertical-align:middle;display:inline-block;width:80%'

    return u'%s' % output



from datetime import datetime, timedelta
from django.db.models import Count
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
import operator

from auth.models import Learner


class ParticipantFilter(admin.SimpleListFilter):
    title = _('Participant')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        result = set([c.learner for c in Learner.objects.all()])
        return [(c.id, c.first_name + ' ' + c.last_name)
                for c in sorted(result,key=operator.attrgetter('first_name'))]


    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(participant__learner__id=self.value())


class FirstNameFilter(admin.SimpleListFilter):
    title = _('First Name')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        return Learner.objects.all().values_list('id', 'first_name').order_by('first_name')

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(participant__learner__id=self.value())


class LastNameFilter(admin.SimpleListFilter):
    title = _('Last Name')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        return Learner.objects.all().values_list('id', 'last_name').order_by('last_name')

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(participant__learner__id=self.value())


class MobileFilter(admin.SimpleListFilter):
    title = _('Mobile')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        return Learner.objects.all().values_list('id', 'mobile').order_by('mobile')

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(participant__learner__id=self.value())


class LearnerFilter(admin.SimpleListFilter):
    title = _('Learner')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        result = set([c.learner for c in Learner.objects.all()])
        return [(c.id, c.first_name + ' ' + c.last_name)
                for c in sorted(result,key=operator.attrgetter('first_name'))]

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(learner__id=self.value())

class ParticipantFirstNameFilter(admin.SimpleListFilter):
    title = _('First Name')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        return Learner.objects.all().values_list('id', 'first_name').order_by('first_name')

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(learner__id=self.value())


class ParticipantLastNameFilter(admin.SimpleListFilter):
    title = _('Last Name')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        return Learner.objects.all().values_list('id', 'last_name').order_by('last_name')

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(learner__id=self.value())


class ParticipantMobileFilter(admin.SimpleListFilter):
    title = _('Mobile')
    parameter_name = 'id'

    def lookups(self, request, model_admin):
        return Learner.objects.all().values_list('id', 'mobile').order_by('mobile')

    def queryset(self, request, queryset):
        if self.value() is None:
            return queryset
        else:
            return queryset.filter(learner__id=self.value())



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import DataMigration
from django.db import models

class Migration(DataMigration):

    def forwards(self, orm):
        for module in orm.Module.objects.all():
            if module.course:
                course_module = orm.CourseModuleRel.objects.create(
                    module=module,
                    course=module.course
                )
                course_module.save()


    def backwards(self, orm):
        "Write your backwards methods here."

    models = {
        u'organisation.course': {
            'Meta': {'object_name': 'Course'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '500', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '500', 'unique': 'True', 'null': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '50', 'blank': 'True'})
        },
        u'organisation.coursemodulerel': {
            'Meta': {'object_name': 'CourseModuleRel'},
            'course': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['organisation.Course']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'module': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['organisation.Module']"})
        },
        u'organisation.module': {
            'Meta': {'object_name': 'Module'},
            'course': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['organisation.Course']", 'null': 'True'}),
            'courses': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'modules'", 'symmetrical': 'False', 'through': u"orm['organisation.CourseModuleRel']", 'to': u"orm['organisation.Course']"}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '500', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '500', 'unique': 'True', 'null': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'})
        },
        u'organisation.organisation': {
            'Meta': {'object_name': 'Organisation'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '500', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '500', 'unique': 'True', 'null': 'True'}),
            'website': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'})
        },
        u'organisation.school': {
            'Meta': {'object_name': 'School'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '500', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '500', 'unique': 'True', 'null': 'True'}),
            'organisation': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['organisation.Organisation']", 'null': 'True'}),
            'website': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'})
        }
    }

    complete_apps = ['organisation']
    symmetrical = True



from setuptools import setup, find_packages

setup(
    name='django-mobileu',
    version='1.1.0',
    packages=find_packages(),
    install_requires=[
        'Django==1.6.5',
        'South==0.8.4',
        'Celery',
        'django-grappelli==2.5.3',
        'django-summernote==0.5.13',
        'django-import-export==0.2.2',
        'django-celery',
        'Pillow==2.4.0',
        'psycopg2==2.5.3',
        'koremutake==1.0.5',
        'requests==2.3.0',
        'go_http==0.1.1',
        'django_bleach',
        'beautifulsoup4',
    ],
    url='www.praekelt.co.za',
    license='',
    author='praekelt',
    author_email='info@praekelt.co.za',
    description='The MobileU MVP framework allows other developers to '
                'easily build mobile education sites.'
)
